Learn R Programming

stripless (version 1.0-3)

stripless-internal: Unexported Utility and xyLayout Functions

Description

Unexported functions not intended to be directly called by users.

For xyLayout: Unexported generic and methods used by strucplot to create, check and/or fix a xyLayout list.

Usage

check2lvl(d, sep = ".")
make_2level_with_center(lvls, sep = ".")
makeSpacings(spacings, levelLength)
chkSpacings(spacings)
xyLayout(xylay, ...)
"xyLayout"(xylay = list(), n = stop("Number of conditioning factors is missing"))
"xyLayout"(xylay, n)
"xyLayout"(xylay, n)
"xyLayout"(..., n)

Arguments

d
Condition list from strucParseFormula to be checked to see if it represents a 2 level design with center point.
sep
sep argument for paste().
lvls
A list of length 3 character vectors that are the level names of factors in a design to be checked.
spacings
A non-decreasing vector of positive values
levelLength
An integer vector giving the number of levels per factor at each level of the plotting hierarchy
xylay
An appropriate list, matrix, or vector for determining the plot structure. Can also be missing, length 0, etc.
n
The number of conditioning factors. The integers in the combined list that is created will be a permutation of 1, 2, ... ,n .
...
x and/or y vector for xylay list. The remaining component will be constructed as needed.

Value

For xyLayout: a list of class "xyLayout" suitable for the xyLayout argument of strucplot.

Details

Brief utility function descriptions:

xyLayout: The various methods provide convenience and flexibility for specifying the xyLayout list argument that controls the format of strucplot displays. Essentially any sensible way of specifying xyLayout should work. See the Help page for strucplot for details.

See Also

strucplot