Learn R Programming

stripless (version 1.0-3)

stripless-package: Trellis Displays Without Strips For Lattice Graphics

Description

Stripless provides a simple interface to make trellis plots without strip labels using lattice graphics. Instead of having strip labels identify each panel's settings of the conditioning variables, their position in a structured row/column layout encodes this information, and a legend decodes them. This avoids cluttering the plot area with redundant layers of strip labels when there are many conditioning variables, as is often the case for factorial designs, especially the (fractions of) two level factorials widely used in industry.

Arguments

Details

The package consists of a generic strucplot function and methods, an associated print method for objects inheriting from class "structured", and some (currently 1) additional trellis panel functions. This functionality is implemented as a wrapper to lattice's xyplot function, so all other plot specifications (panel functions, colors, titles, etc.) are given through the usual xyplot arguments.

See strucplot for a full explanation of the structured plotting paradigm, how strucplot implements it, and examples illustrating how it works.