For xyLayout: Unexported generic and methods used by strucplot to
create, check and/or fix a xyLayout list.
check2lvl(d, sep = ".")
make_2level_with_center(lvls, sep = ".")
makeSpacings(spacings, levelLength)
chkSpacings(spacings)
xyLayout(xylay, ...)
"xyLayout"(xylay = list(), n = stop("Number of conditioning factors is missing"))
"xyLayout"(xylay, n)
"xyLayout"(xylay, n)
"xyLayout"(..., n)paste().xylay list. The remaining component will be
constructed as needed.xyLayout: a list of class "xyLayout" suitable for the xyLayout argument of strucplot.
xyLayout:
The various methods provide convenience and flexibility for specifying
the xyLayout list argument that controls the format of strucplot
displays. Essentially any sensible way of specifying xyLayout should
work. See the Help page for strucplot for details.
strucplot