strucplot function and methods, an
associated print method for objects inheriting from class
"structured", and some (currently 1) additional trellis
panel functions. This functionality is implemented as a wrapper
to lattice's xyplot function, so all other plot specifications
(panel functions, colors, titles, etc.) are given through the usual
xyplot arguments.See strucplot for a full explanation of the structured plotting
paradigm, how strucplot implements it, and examples illustrating how
it works.